@@ -4,16 +4,18 @@ class HGVSError(Exception):
 class HGVSParseError(HGVSError):
     pass
 
-#TODO: Stick to HGVS prefix on exceptions
-class InvalidIntervalError(HGVSError):
+class HGVSInvalidIntervalError(HGVSError):
     pass
 
-class InvalidHGVSVariantError(HGVSError):
+class HGVSInvalidVariantError(HGVSError):
     pass
 
 class HGVSValidationError(HGVSError):
     pass
 
+class HGVSDataNotAvailableError(HGVSError):
+    pass
+
 
 ## <LICENSE>
 ## Copyright 2014 HGVS Contributors (https://bitbucket.org/invitae/hgvs)
